pub enum Backend {
Protoc,
Buf,
}Expand description
Code generation backend selection.
Determines which tool will be used to generate Python code from proto files.
Variants
Protoc
Use the standard protoc compiler for code generation. This is the currently supported and default backend.
Buf
Use buf generate for code generation. This backend is planned for future versions but not yet implemented.