Module fds
python_
proto_
importer
0.1.4
Module fds
Module Items
Functions
In python_
proto_
importer::
postprocess
python_proto_importer
::
postprocess
Module
fds
Functions

collect_
generated_
basenames_
from_
bytes
Decode bytes into FileDescriptorSet and collect generated module basenames like “foo_pb2”, “foo_pb2_grpc” for each file in the set.
is_
proto_
generated_
module
Given a pool and a relative module path, determine if an import target corresponds to a .proto-derived module according to the pool entries. For now, this is a placeholder returning true if suffix matches _pb2 or _pb2_grpc.
load_
fds_
from_
bytes
Load a FileDescriptorSet (binary) and return a DescriptorPool