Module package_structure

Module package_structure 

Functions

determine_package_structure
Intelligent package structure determination Prefers PYTHONPATH to point at the directory which contains the “package root”. If the parent of out_abs is a package (has init.py), use its parent as PYTHONPATH and set package_name to “{parent}.{out}”. Otherwise use the parent as PYTHONPATH and package_name to out.
determine_package_structure_legacy
Legacy package structure determination Simply uses parent as PYTHONPATH and out_name as package_name