Module fds

Module fds 

Functions

collect_generated_basenames_from_bytes
Decode bytes into FileDescriptorSet and collect generated module basenames like “foo_pb2”, “foo_pb2_grpc” for each file in the set.
is_proto_generated_module
Given a pool and a relative module path, determine if an import target corresponds to a .proto-derived module according to the pool entries. For now, this is a placeholder returning true if suffix matches _pb2 or _pb2_grpc.
load_fds_from_bytes
Load a FileDescriptorSet (binary) and return a DescriptorPool