Module rel_imports
python_
proto_
importer
0.1.4
Module rel_
imports
Module Items
Functions
In python_
proto_
importer::
postprocess
python_proto_importer
::
postprocess
Module
rel_
imports
Functions

rewrite_
file_
for_
relative_
imports
Very small scaffold for future import rewriting. For now, it only identifies candidate lines and returns count.
scan_
and_
report
Walk output tree and report count of candidate files/lines (dry-run).